@@ -78,15 +78,10 @@ namespace Glom
 
 Frame_Glom::Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : PlaceHolder(cobject, builder),
-  m_pLabel_Table(0),
-  m_box_header(0),
-  m_box_footer(0),
-  m_pLabel_Mode(0),
-  m_pLabel_userlevel(0),
-  m_pBox_RecordsCount(0),
-  m_pLabel_RecordsCount(0),
-  m_pLabel_FoundCount(0),
-  m_pButton_FindAll(0),
+  m_pLabel_Table_DataMode(0),
+  m_pLabel_Table_FindMode(0),
+  m_Box_RecordsCount(false, Utils::DEFAULT_SPACING_SMALL),
+  m_Button_FindAll(_("Find All")),
   m_pBox_Mode(0),
 #ifndef GLOM_ENABLE_MAEMO
   m_pBox_Tables(0),
@@ -112,22 +107,20 @@ Frame_Glom::Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>
   m_dialog_progess_connection_cleanup(0),
   m_pDialogConnection(0)
 {
-  //Load widgets from glade file:
-  builder->get_widget("label_table_name", m_pLabel_Table);
-
-  builder->get_widget("hbox_header", m_box_header);
-  builder->get_widget("hbox_footer", m_box_footer);
-  builder->get_widget("label_mode", m_pLabel_Mode);
-  builder->get_widget("label_user_level", m_pLabel_userlevel);
-
   //Hide unnecessary widgets on maemo that take too much space,
   //and reduce the border width:
   #ifdef GLOM_ENABLE_MAEMO
-  m_box_header->hide();
-  m_box_footer->hide();
   set_border_width(Glom::Utils::DEFAULT_SPACING_LARGE);
   #endif
 
+  m_pLabel_Table_DataMode = Gtk::manage(new Gtk::Label(_("No Table Selected")));
+  m_pLabel_Table_DataMode->show();
+  m_Notebook_Data.set_action_widget(m_pLabel_Table_DataMode, Gtk::PACK_START);
+
+  m_pLabel_Table_FindMode = Gtk::manage(new Gtk::Label(_("No Table Selected")));
+  m_pLabel_Table_FindMode->show();
+  m_Notebook_Find.set_action_widget(m_pLabel_Table_FindMode, Gtk::PACK_START);
+
   //QuickFind widgets:
   //We don't use Glade for these, so it easier to modify them for the Maemo port.
   m_pBox_QuickFind = Gtk::manage(new Gtk::HBox(false, Utils::DEFAULT_SPACING_SMALL));
@@ -164,12 +157,17 @@ Frame_Glom::Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>
   placeholder_quickfind->add(*m_pBox_QuickFind);
   #endif //GLOM_ENABLE_MAEMO
 
-
-  builder->get_widget("hbox_records_count", m_pBox_RecordsCount);
-  builder->get_widget("label_records_count", m_pLabel_RecordsCount);
-  builder->get_widget("label_records_found_count", m_pLabel_FoundCount);
-  builder->get_widget("button_find_all", m_pButton_FindAll);
-  m_pButton_FindAll->signal_clicked().connect(
+  //Add the Records/Found widgets at the right of the notebook tabs:
+  m_Box_RecordsCount.pack_start(
+    *Gtk::manage(new Gtk::Label(_("Records:"))), Gtk::PACK_SHRINK);
+  m_Box_RecordsCount.pack_start(m_Label_RecordsCount, Gtk::PACK_SHRINK);
+  m_Box_RecordsCount.pack_start(
+    *Gtk::manage(new Gtk::Label(_("Found:"))), Gtk::PACK_SHRINK);
+  m_Box_RecordsCount.pack_start(m_Label_FoundCount, Gtk::PACK_SHRINK);
+  m_Box_RecordsCount.pack_start(m_Button_FindAll, Gtk::PACK_SHRINK);
+  m_Box_RecordsCount.show_all();
+  m_Notebook_Data.set_action_widget(&m_Box_RecordsCount, Gtk::PACK_END);
+  m_Button_FindAll.signal_clicked().connect(
     sigc::mem_fun(*this, &Frame_Glom::on_button_find_all) );
 
   builder->get_widget_derived("vbox_mode", m_pBox_Mode);
@@ -366,14 +364,10 @@ bool Frame_Glom::set_mode(enumModes mode)
       m_pEntry_QuickFind->grab_focus();
       //m_pButton_QuickFind->grab_default();
     }
-
-    m_pBox_RecordsCount->hide();
   }
   else
   {
     m_pBox_QuickFind->hide();
-
-    m_pBox_RecordsCount->show();
   }
 
   return changed;
@@ -409,7 +403,6 @@ void Frame_Glom::show_table_allow_empty(const Glib::ustring& table_name, const G
 
   //Show the table:
   m_table_name = table_name;
-  Glib::ustring strMode;
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   //Update the document with any new information in the database if necessary (though the database _should never have changed information)
   update_table_in_document_from_database();
@@ -426,7 +419,6 @@ void Frame_Glom::show_table_allow_empty(const Glib::ustring& table_name, const G
   {
     case(MODE_Data):
     {
-      strMode = _("Data");
       FoundSet found_set;
 
       //Start with the last-used found set (sort order and where clause)
@@ -477,7 +469,6 @@ void Frame_Glom::show_table_allow_empty(const Glib::ustring& table_name, const G
     }
     case(MODE_Find):
     {
-      strMode = _("Find");
       m_Notebook_Find.init_db_details(m_table_name, get_active_layout_platform(get_document()));
       set_mode_widget(m_Notebook_Find);
       break;
@@ -485,13 +476,10 @@ void Frame_Glom::show_table_allow_empty(const Glib::ustring& table_name, const G
     default:
     {
       std::cout << "debug: " << G_STRFUNC << ": Unexpected mode" << std::endl;
-      strMode = _("Unknown");
       break;
     }
   }
 
-  m_pLabel_Mode->set_text(strMode);
-
   show_table_title();
 
   //List the reports and print layouts in the menus:
@@ -520,7 +508,7 @@ void Frame_Glom::show_no_table()
 }
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-void Frame_Glom::on_menu_userlevel_Developer(const Glib::RefPtr<Gtk::RadioAction>& action, const Glib::RefPtr<Gtk::RadioAction>& operator_action)
+void Frame_Glom::on_menu_developer_developer(const Glib::RefPtr<Gtk::RadioAction>& action, const Glib::RefPtr<Gtk::RadioAction>& operator_action)
 {
   if(action && action->get_active())
   {
@@ -595,7 +583,7 @@ void Frame_Glom::on_menu_userlevel_Developer(const Glib::RefPtr<Gtk::RadioAction
   }
 }
 
-void Frame_Glom::on_menu_userlevel_Operator(const Glib::RefPtr<Gtk::RadioAction>& action)
+void Frame_Glom::on_menu_developer_operator(const Glib::RefPtr<Gtk::RadioAction>& action)
 {
   if(action &&  action->get_active())
   {
@@ -1093,7 +1081,7 @@ void Frame_Glom::show_layout_toolbar (bool show)
 
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-void Frame_Glom::on_menu_Mode_Toggle()
+void Frame_Glom::on_menu_Edit_Find()
 {
   //Switch back to data mode if we are in find mode.
   if(m_Mode == MODE_Find)
@@ -1399,7 +1387,7 @@ void Frame_Glom::on_button_quickfind()
   else
   {
     const Gnome::Gda::SqlExpr where_clause = Utils::get_find_where_clause_quick(get_document(), m_table_name, Gnome::Gda::Value(criteria));
-    //std::cout << "debug: " << G_STRFUNC << ": where_clause=" << where_clause << std::endl;
+    //std::cout << "debug: " << G_STRFUNC << ": where_clause=" << where_clause.serialize() << std::endl;
     on_notebook_find_criteria(where_clause);
   }
 }
@@ -1446,17 +1434,9 @@ void Frame_Glom::on_notebook_find_criteria(const Gnome::Gda::SqlExpr& where_clau
   }
 }
 
-void Frame_Glom::on_userlevel_changed(AppState::userlevels userlevel)
+void Frame_Glom::on_userlevel_changed(AppState::userlevels /* userlevel */)
 {
-  //show user level:
-  //The _C macro provides translator context.
-  Glib::ustring user_level_name = C_("Mode", "Operator");
-  if(userlevel == AppState::USERLEVEL_DEVELOPER)
-    user_level_name = C_("Mode", "Developer");
-
-  if(m_pLabel_userlevel)
-    m_pLabel_userlevel->set_text(user_level_name);
-
+  //show user level in the window title:
   show_table_title();
 }
 
@@ -1483,10 +1463,12 @@ void Frame_Glom::show_table_title()
   if(app)
     app->set_title(document->get_name() + ": " + table_label);
 
-  // xx-large is too large on maemo, using far too much (vertical) space.
   // We hide this anyway: m_pLabel_Table->set_markup("<b>" + table_label + "</b>");
 #else
-  m_pLabel_Table->set_markup("<b><span size=\"xx-large\">" + table_label + "</span></b>"); //Show the table title in large text, because it's very important to the user.
+  //Show the table title in bold text, because it's important to the user.
+  const Glib::ustring title = "<b>" + table_label + "</b>";
+  m_pLabel_Table_DataMode->set_markup(title);
+  m_pLabel_Table_FindMode->set_markup(title);
 #endif
 }
 
@@ -2589,7 +2571,7 @@ void Frame_Glom::update_records_count()
     else
       str_count_found = str_count_all;
 
-    m_pButton_FindAll->hide();
+    m_Button_FindAll.hide();
   }
   else
   {
@@ -2597,11 +2579,11 @@ void Frame_Glom::update_records_count()
     the_stream << count_found;
     the_stream >> str_count_found;
 
-    m_pButton_FindAll->show();
+    m_Button_FindAll.show();
   }
 
-  m_pLabel_RecordsCount->set_text(str_count_all);
-  m_pLabel_FoundCount->set_text(str_count_found);
+  m_Label_RecordsCount.set_text(str_count_all);
+  m_Label_FoundCount.set_text(str_count_found);
 
 }
 
