@@ -103,20 +103,7 @@ Gnome::Gda::Value auto_increment_insert_first_if_necessary(const Glib::ustring&
   */
 Gnome::Gda::Value get_next_auto_increment_value(const Glib::ustring& table_name, const Glib::ustring& field_name);
 
-/** Use this, for instance, when deleting a table.
- */
-void remove_auto_increment(const Glib::ustring& table_name, const Glib::ustring& field_name);
-
-//TODO: It would be nice to use sharedptr<const Relationship>& instead of sharedptr<Relationship>&,
-//but it does not seem possible to pass a sharedptr<const Relationship> for a sharedptr<const Relationship>&.
-
-/** Decides whether a field should have an Open button next to it,
- * allowing the user to navigate to a related record.
- *
- * @param layout_item A field on a layout. This must have full field details.
- * @param field_used_in_relationship_to_one A relationship, if the field identifies a single record, so a Find button would also make sense, to choose the ID, in editing mode.
- */
-bool layout_field_should_have_navigation(const Glib::ustring& table_name, const sharedptr<const LayoutItem_Field>& layout_item, const Document* document, sharedptr<Relationship>& field_used_in_relationship_to_one);
+void layout_item_fill_field_details(Document* document, const Glib::ustring& parent_table_name, sharedptr<LayoutItem_Field>& layout_item);
 
 } //namespace DbUtils
 
