@@ -120,6 +120,9 @@ protected:
   Gtk::Button* m_button_formatting;
   Gtk::Button* m_button_edit;
   Gtk::Label* m_label_table_name;
+  
+  Gtk::Box* m_hbox_rows_count;
+  Gtk::SpinButton* m_spinbutton_rows_count;
 
   Glib::RefPtr<TreeStore_Layout> m_model_items;
 };
