@@ -26,7 +26,7 @@
 #include <libglom/data_structure/layout/layoutitem_button.h>
 #include <glom/base_db.h>
 
-#include <gtksourceviewmm/sourceview.h>
+#include <gtksourceviewmm/view.h>
 
 namespace Glom
 {
@@ -51,7 +51,7 @@ private:
   void on_button_test_script();
 
   Gtk::Entry* m_entry_title;
-  Gsv::SourceView* m_text_view_script;
+  Gsv::View* m_text_view_script;
   Gtk::Button* m_button_test_script;
 
   sharedptr<LayoutItem_Button> m_script;
