@@ -18,16 +18,13 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef ADDDEL_H
-#define ADDDEL_H
+#ifndef GLOM_UTLITY_WIDGETS_ADDDEL_H
+#define GLOM_UTLITY_WIDGETS_ADDDEL_H
 
+#include <gtkmm.h>
 #include <libglom/data_structure/field.h>
+#include <libgdamm.h>
 #include <gtkmm/builder.h>
-#include <gtkmm/treeview.h>
-#include <gtkmm/scrolledwindow.h>
-#include <gtkmm/box.h>
-#include <gtkmm/liststore.h>
-#include <gtkmm/uimanager.h>
 
 #include <vector>
 #include <map>
@@ -209,7 +206,12 @@ public:
 
   bool get_model_column_index(guint view_column_index, guint& model_column_index);
 
+  /** Get the last row. This will generally be the placeholder row.
+   */
   Gtk::TreeModel::iterator get_last_row();
+
+  /** Get the last row. This will generally be the placeholder row.
+   */
   Gtk::TreeModel::iterator get_last_row() const;
 
 protected:
@@ -333,4 +335,4 @@ guint AddDel::treeview_append_column(const Glib::ustring& title, const Gtk::Tree
 } //namespace Glom
 
 
-#endif //ADDDEL_H
+#endif // GLOM_UTLITY_WIDGETS_ADDDEL_H
