@@ -1,6 +1,6 @@
 /* Glom
  *
- * Copyright (C) 2001-2004 Murray Cumming
+ * Copyright (C) 2001-2011 Murray Cumming
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -222,9 +222,19 @@ void ImageGlom::on_ev_job_finished(EvJob* job)
 	ev_view_set_loading(m_ev_view, FALSE);
 }
 
+const GdaBinary* ImageGlom::get_binary() const
+{
+  const GdaBinary* gda_binary = 0;
+  if(m_original_data.get_value_type() == GDA_TYPE_BINARY)
+    gda_binary = gda_value_get_binary(m_original_data.gobj());
+  
+  return gda_binary;
+}
+
 Glib::ustring ImageGlom::get_mime_type() const
 {
-  const GdaBinary* gda_binary = gda_value_get_binary(m_original_data.gobj());
+  const GdaBinary* gda_binary = get_binary();
+
   if(!gda_binary)
     return Glib::ustring();
     
@@ -314,7 +324,6 @@ void ImageGlom::show_image_data()
     
   //Clear all possible display widgets:
   m_pixbuf_original.reset();
-  m_pixbuf_thumbnail.reset();
   m_image.set(Glib::RefPtr<Gdk::Pixbuf>()); //TODO: Add an unset() to gtkmm.
   
   if(m_ev_document_model)
@@ -331,6 +340,21 @@ void ImageGlom::show_image_data()
     gtk_widget_show(GTK_WIDGET(m_ev_view));
     gtk_container_add(GTK_CONTAINER(m_frame.gobj()), GTK_WIDGET(m_ev_view));
 
+    // Try loading from data in memory:
+    // TODO: Uncomment this if this API is added: https://bugzilla.gnome.org/show_bug.cgi?id=654832
+    /*
+    const GdaBinary* gda_binary = get_binary();
+    if(!gda_binary || !gda_binary->data || !gda_binary->binary_length)
+    {
+       std::cerr << G_STRFUNC << "Data was null or empty." << std::endl;
+      return;
+    }
+    
+    EvJob *job = ev_job_load_new_with_data(
+      (char*)gda_binary->data, gda_binary->binary_length);
+    */
+    //TODO: Test failure asynchronously.
+    
     const Glib::ustring uri = save_to_temp_file(false /* don't show progress */);
     if(uri.empty())
     {
@@ -375,52 +399,8 @@ void ImageGlom::show_image_data()
     }
     else
     {
-      //Try to use a thumbnail via GFile:
-      //TODO: Do this asynchronously:
-      const Glib::ustring uri = save_to_temp_file(false /* don't show progress */);
-      if(uri.empty())
-      {
-        std::cerr << G_STRFUNC << "Could not save temp file to get a thumbnail." << std::endl;
-      }
-      else
-      {
-        Glib::RefPtr<Gio::File> file = Gio::File::create_for_uri(uri);
-        Glib::RefPtr<const Gio::FileInfo> file_info;
-
-        try
-        {
-          file_info = file->query_info(
-            G_FILE_ATTRIBUTE_THUMBNAIL_PATH ","
-            G_FILE_ATTRIBUTE_THUMBNAILING_FAILED ","
-            G_FILE_ATTRIBUTE_STANDARD_ICON);
-        }
-        catch(const Glib::Error& ex)
-        {
-          std::cerr << G_STRFUNC << ": query_info() failed: " << ex.what() << std::endl;
-        }
-      
-        if(file_info)
-        {
-          const std::string filepath = 
-            file_info->get_attribute_byte_string(G_FILE_ATTRIBUTE_THUMBNAIL_PATH);
-          const bool failed = 
-            file_info->get_attribute_boolean(G_FILE_ATTRIBUTE_THUMBNAILING_FAILED);
-          if(!filepath.empty())
-            m_pixbuf_original = Gdk::Pixbuf::create_from_file(filepath);
-          else
-          {
-            std::cerr << G_STRFUNC << ": Could not get attribute G_FILE_ATTRIBUTE_THUMBNAIL_PATH. failed=" << failed << std::endl;
-            
-            //Use the standard icon instead:
-            icon = file_info->get_icon();
-            if(!icon)
-            {
-               std::cerr << G_STRFUNC << ": Could not get G_FILE_ATTRIBUTE_STANDARD_ICON" << std::endl;
-            }
-            
-          }
-        }
-      }
+      //Get an icon for the file type;
+      icon = Gio::content_type_get_icon(mime_type);
     }
     
     if(m_pixbuf_original)
@@ -527,14 +507,87 @@ void ImageGlom::on_menupopup_activate_open_file_with()
   open_with(app_info);
 }
 
+static void make_file_read_only(const Glib::ustring& uri)
+{
+  std::string filepath;
+
+  try
+  {
+    filepath = Glib::filename_from_uri(uri);
+  }
+  catch(const Glib::Error& ex)
+  {
+    std::cerr << G_STRFUNC << "Exception: " << ex.what() << std::endl;
+    return;
+  }
+  
+  if(filepath.empty())
+  {
+    std::cerr << G_STRFUNC << ": filepath is empty." << std::endl;
+  }
+  
+  const int result = chmod(filepath.c_str(), S_IRUSR);
+  if(result != 0)
+  {
+    std::cerr << G_STRFUNC << ": chmod() failed." << std::endl;
+  }
+  
+  //Setting the attribute via gio gives us this exception:
+  //"Setting attribute access::can-write not supported"
+  /*
+  Glib::RefPtr<Gio::File> file = Gio::File::create_for_uri(uri);
+
+  Glib::RefPtr<Gio::FileInfo> file_info;
+
+  try
+  {
+    file_info = file->query_info(G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE);
+  }
+  catch(const Glib::Error& ex)
+  {
+    std::cerr << G_STRFUNC << ": query_info() failed: " << ex.what() << std::endl;
+    return;
+  }
+  
+  if(!file_info)
+  {
+    std::cerr << ": file_info is null" << std::endl;
+    return;
+  }
+  
+  const bool can_write =
+    file_info->get_attribute_boolean(G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE);
+  if(!can_write)
+    return;
+    
+  file_info->set_attribute_boolean(G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE, false);
+  
+  try
+  {
+    file->set_attributes_from_info(file_info);
+  }
+  catch(const Glib::Error& ex)
+  {
+    std::cerr << G_STRFUNC << ": set_attributes_from_info() failed: " << ex.what() << std::endl;
+  }
+  */
+}
+
 Glib::ustring ImageGlom::save_to_temp_file(bool show_progress)
 {
   Glib::ustring uri;
   
   //Get a temporary file path:
   std::string filepath;
-  const int filehandle = Glib::file_open_tmp(filepath);
-  ::close(filehandle);
+  try
+  {
+    const int filehandle = Glib::file_open_tmp(filepath);
+    ::close(filehandle);
+  }
+  catch(const Glib::Error& ex)
+  {
+    std::cerr << G_STRFUNC << ": Glib::file_open_tmp() failed" << std::endl;
+  }
   
   if(filepath.empty())
   {
@@ -555,6 +608,13 @@ Glib::ustring ImageGlom::save_to_temp_file(bool show_progress)
     uri = Glib::ustring();
     std::cerr << G_STRFUNC << ": save_file() failed." << std::endl;
   }
+  else
+  {
+    //Don't let people easily edit the saved file,
+    //because they would lose data when it is automatically deleted later.
+    //Also they might think that editing it will change it in the database.
+    make_file_read_only(uri);
+  }
 
   return uri;
 }
@@ -643,7 +703,7 @@ bool ImageGlom::save_file_sync(const Glib::ustring& uri)
   //because we don't want to offer feedback.
   //Ideally, EvView would just load from data anyway.
   
-  const GdaBinary* gda_binary = gda_value_get_binary(m_original_data.gobj());
+  const GdaBinary* gda_binary = get_binary();
   if(!gda_binary)
   {
     std::cerr << G_STRFUNC << ": GdaBinary is null" << std::endl;
@@ -684,7 +744,7 @@ bool ImageGlom::save_file(const Glib::ustring& uri)
   if(pApp)
     dialog_save->set_transient_for(*pApp);
 
-  const GdaBinary* gda_binary = gda_value_get_binary(m_original_data.gobj());
+  const GdaBinary* gda_binary = get_binary();
   if(!gda_binary)
     return false;
 
@@ -692,6 +752,7 @@ bool ImageGlom::save_file(const Glib::ustring& uri)
   dialog_save->save(uri);
 
   dialog_save->run();
+
   return true;
 }
 
@@ -765,7 +826,7 @@ void ImageGlom::on_clipboard_get(Gtk::SelectionData& selection_data, guint /* in
   
   if(target == mime_type)
   {
-    const GdaBinary* gda_binary = gda_value_get_binary(m_original_data.gobj());
+    const GdaBinary* gda_binary = get_binary();
     if(!gda_binary)
       return;
     
